@@ -207,18 +207,18 @@ class AVISO_fetch(object):
         Latlimits = numpy.arange(Lat.shape[0])[(Lat[:]>=limits["latini"]) & (Lat[:]<=limits["latfin"])]
         Latlimits = [Latlimits[0],Latlimits[-1]]
 
-        lat = Lat[Latlimits[0]:Latlimits[-1]]
+        lat = Lat[Latlimits[0]:Latlimits[-1]+1]
 
         if limits['lonfin'] > limits['lonini']:
             Lonlimits = numpy.arange(Lon.shape[0])[(Lon[:]>=limits["lonini"]) & (Lon[:]<=limits["lonfin"])]
             Lonlimits=[Lonlimits[0],Lonlimits[-1]]
 
-            lon = Lon[Lonlimits[0]:Lonlimits[-1]]
+            lon = Lon[Lonlimits[0]:Lonlimits[-1]+1]
         else:
             Lonlimits = [np.nonzero(Lon>=limits['lonini'])[0][0], 
-                    np.nonzero(Lon<=limits['lonfin'])[0][-1]+1] 
+                    np.nonzero(Lon<=limits['lonfin'])[0][-1]] 
 
-            lon = np.append(Lon[Lonlimits[0]:],Lon[:Lonlimits[1]])
+            lon = np.append(Lon[Lonlimits[0]:],Lon[:Lonlimits[1]+1])
                     
 
         self.cfg['limits']['Latlimits'] = Latlimits
@@ -242,7 +242,6 @@ class AVISO_fetch(object):
     def download_data(self):
         """ Download h and uv in blocks
         """
-
         # Will download blocks of at most 5MB
         #   i.e. 4e7 floats of 32bits.
         dblocks = max(1, int(4e7/self.slice_size))
@@ -282,10 +281,10 @@ class AVISO_fetch(object):
                     print "Try n: %s" % i
                     try:
                         if Lonlimits[1] > Lonlimits[0]:
-                            tmp = dataset[b1:b2:self.cfg['limits']['t_step'], Lonlimits[0]:Lonlimits[-1],Latlimits[0]:Latlimits[-1]]
+                            tmp = dataset[b1:b2:self.cfg['limits']['t_step'], Lonlimits[0]:Lonlimits[-1]+1,Latlimits[0]:Latlimits[-1]+1]
                         else:
-                            tmp1 = dataset[b1:b2:self.cfg['limits']['t_step'], Lonlimits[0]:,Latlimits[0]:Latlimits[-1]]
-                            tmp2 = dataset[b1:b2:self.cfg['limits']['t_step'], :Lonlimits[-1],Latlimits[0]:Latlimits[-1]]
+                            tmp1 = dataset[b1:b2:self.cfg['limits']['t_step'], Lonlimits[0]:,Latlimits[0]:Latlimits[-1]+1]
+                            tmp2 = dataset[b1:b2:self.cfg['limits']['t_step'], :Lonlimits[-1]+1,Latlimits[0]:Latlimits[-1]+1]
                             tmp = np.append(tmp1, tmp2, axis=1)
                         data[v][ind] = tmp.swapaxes(1,2).astype('f')
                         break
@@ -299,11 +298,18 @@ class AVISO_fetch(object):
 class Products(object):
     """ Calculate some products from the downloaded data
     """
+    from ringslegacy import okuboweiss
     def __init__(self, cfg):
         self.cfg = cfg
         self.file = os.path.join(self.cfg['datadir'], self.cfg['filename'])
-        self.nc = pupynere.netcdf_file(self.file,'a')
-        for tn in range(nc.dimensions['time']):
+        self.nc = netCDF4.Dataset(self.file, 'a', format='NETCDF4')
+
+        W = nc.createVariable('W', 'f', ('time', 'lat', 'lon'))
+        W.missing_value = nc.variables['u'].missing_value
+        zeta = nc.createVariable('zeta', 'f', ('time', 'lat', 'lon'))
+        zeta.missing_value = nc.variables['u'].missing_value
+
+        for tn in range(nc.variables['time'].size):
             data = {'t': datetime.strptime(nc.variables['time'].units, 
                 'hours since %Y-%m-%d') + timedelta(hours=float(nc.variables['time'][tn])), 
                 'Lat': ma.array(nc.variables['Lat'][:]),
@@ -312,11 +318,15 @@ class Products(object):
                     nc.variables['u'].missing_value),
                 'v': ma.masked_values(nc.variables['v'][tn], 
                     nc.variables['v'].missing_value),
-                }
+                } 
 
-#products = okuboweiss.okuboweiss(data)
+            products = okuboweiss.okuboweiss(data)
+
+            W[tn] = products['W']
+            zeta[tn] = products['zeta']
+
+        nc.close()
 
-#products = okuboweiss.OkuboWeiss(data, cfg['okuboweiss']) %, logname = metadata['log']['logname'])
 
 
 
